@@ -337,6 +337,9 @@ class B2GPerfTest(object):
         self.logger.debug('Setting content volume to %d' % safe_volume)
         self.data_layer.set_setting('audio.volume.content', safe_volume)
 
+        self.logger.debug('Switching off keyboard first time use screen')
+        self.data_layer.set_setting('keyboard.ftu.enabled', False)
+
         self.logger.debug('Unlocking device')
         gaiatest.LockScreen(self.marionette).unlock()
 
@@ -658,7 +661,7 @@ class B2GPerfScrollHomescreenTest(B2GPerfScrollTest):
     def scroll(self):
         action = Actions(self.marionette)
         for page in self.marionette.find_elements(By.CSS_SELECTOR,
-                                                  '#icongrid .page')[:-1]:
+                                                  '#icongrid > div')[:-1]:
             self.logger.debug('Swiping to next page of apps')
             action.flick(
                 page,
@@ -669,7 +672,7 @@ class B2GPerfScrollHomescreenTest(B2GPerfScrollTest):
             MarionetteWait(self.marionette, 30).until_not(
                 lambda m: page.is_displayed())
         for page in reversed(self.marionette.find_elements(
-                By.CSS_SELECTOR, '#icongrid .page')[1:]):
+                By.CSS_SELECTOR, '#icongrid > div')[1:]):
             MarionetteWait(self.marionette, 30).until(
                 lambda m: page.is_displayed())
             self.logger.debug('Swiping to previous page of apps')
